@@ -42,7 +42,7 @@ DEFAULT_SPECD_PATH = os.path.join(
     os.path.dirname(__file__), "../../gosdk/specs/"
 )
 
-VERSION = "0.9.11"
+VERSION = "0.9.12"
 COPYRIGHT = "Copyright: GenomOncology, LLC"
 
 
@@ -389,6 +389,72 @@ def annotate_calls(
     ]
 
 
+@gocli.command()
+@click.option(
+    "--async",
+    "-a",
+    "run_async",
+    help="Run in asynchronous mode.",
+    is_flag=True,
+)
+@click.option(
+    "--delete-if-exists",
+    "-d",
+    "delete_if_exists",
+    help="Delete if annotations exist.",
+    is_flag=True,
+)
+@click.option(
+    "--keep_ref_unknown_calls",
+    "-k",
+    "keep_ref_unknown_calls",
+    help="Include homozygous reference and unknown calls.",
+    is_flag=True,
+)
+@options.size_option
+@options.build_option
+@options.pass_state
+def annotate_match(
+    state,
+    run_async,
+    delete_if_exists,
+    keep_ref_unknown_calls,
+):
+    """Get annotations for stream of calls."""
+    if run_async:
+        create_function = kms.create_async_processor
+        sdk_function = kms.annotations.async_annotate_match
+    else:
+        create_function = kms.create_sync_processor
+        sdk_function = kms.annotations.sync_annotate_match
+
+    # get the annotation bundle version once instead of once per batch
+    sdk = state.create_sdk(async_enabled=False)
+    annotation_bundle_version = kms.annotations.get_annotation_bundle_version(
+        sdk
+    )
+
+    return [
+        filter(is_not_skipped_call),
+        filter(
+            filter_out_ref_unknown(
+                keep_ref_unknown_calls=keep_ref_unknown_calls
+            )
+        ),
+        partition_all(
+            state.batch_size
+        ),  # annotate calls is GET, hardcoded batch size
+        create_function(
+            state,
+            sdk_function,
+            delete_if_exists=delete_if_exists,
+            build=state.build,
+            annotation_bundle_version=annotation_bundle_version,
+        ),
+        concat,
+    ]
+
+
 @gocli.command()
 @options.build_option
 @options.pass_state
