@@ -13,7 +13,7 @@ from genomoncology.parse import (
 )
 from genomoncology.parse.ensures import ensure_collection
 from genomoncology.pipeline.converters import obj_to_dict
-from gosdk.models import AnnotationList
+from gosdk.models import AnnotationList, AnnotationMatchList
 
 from genomoncology.cli.const import GRCh37
 
@@ -35,6 +35,83 @@ def hotspot_annotate(data, data_set, data_set_version, sdk=None):
 EXCLUDE_BUILD_FIELDS = ["is_gene_annotation"]
 
 
+@curry
+async def async_annotate_match(
+    data,
+    sdk=None,
+    delete_if_exists=False,
+    build=GRCh37,
+    annotation_bundle_version=None,
+):
+    csra_batch = convert_to_csra([{**d, "build": build} for d in data])
+
+    if csra_batch:
+        annotations_list = await sdk.call_with_retry(
+            sdk.annotations.post_annotations_match,
+            batch=csra_batch,
+            delete_if_exists=delete_if_exists,
+            build=build,
+        )
+    else:
+        annotations_list = None
+
+    annotated_calls = annotate_match_calls(
+        annotations_list,
+        data,
+        annotation_bundle_version,
+    )
+
+    logger.get_logger().debug(
+        "async_annotate_match",
+        call_count=len(data),
+        first_call=data[:1],
+        csra_batch=csra_batch[:4],
+        annotated_count=len(annotated_calls),
+        first_annotated=annotated_calls[:1],
+    )
+
+    return annotated_calls
+
+
+@curry
+def sync_annotate_match(
+    data,
+    sdk=None,
+    delete_if_exists=False,
+    build=GRCh37,
+    annotation_bundle_version=None,
+):
+    csra_batch = convert_to_csra([{**d, "build": build} for d in data])
+
+    annotations_list = (
+        sdk.call_with_retry(
+            sdk.annotations.post_annotations_match,
+            batch=csra_batch,
+            delete_if_exists=delete_if_exists,
+            build=build,
+        )
+        if csra_batch
+        else None
+    )
+
+    annotated_calls = annotate_match_calls(
+        annotations_list,
+        data,
+        annotation_bundle_version,
+    )
+
+    logger.get_logger().debug(
+        "sync_annotate_match",
+        call_count=len(data),
+        call_first=data[:1],
+        csra_batch=csra_batch[:4] if csra_batch else None,
+        annotated_count=len(annotated_calls),
+        annotated_first=annotated_calls[:1],
+    )
+
+    return annotated_calls
+
+
 @curry
 async def async_annotate(
     data,
@@ -237,6 +314,60 @@ def annotate_hotspots(data):
     return annotations
 
 
+def annotate_match_calls(
+    annotations_list, data, annotation_bundle_version
+):
+    func = partial(
+        add_annotation_match,
+        annotations_list,
+        annotation_bundle_version,
+    )
+    annotated_calls = list(map(func, data))
+    return annotated_calls
+
+
+def add_annotation_match(
+    annotations_list: AnnotationMatchList,
+    expected_bundle_version,
+    call: dict,
+):  # pragma: no mccabe
+
+    if annotations_list and is_call_or_variant(call):
+        csra = to_csra(call)
+        annotations = (
+            obj_to_dict(None, annotations_list.get_annotation(csra)) or {}
+        )
+
+        # if the annotation_bundle does not match, raise an exception
+        if expected_bundle_version is not None:
+
+            actual_bundle_version = (
+                annotations.get("annotation_bundle_version")
+                or expected_bundle_version
+            )
+
+            if expected_bundle_version != actual_bundle_version:
+                msg = (
+                    "Annotations Process Terminated due to "
+                    "annotations_bundle_version "
+                    "changing during a run. \n"
+                    "Expected annotation bundle version: {expected} \n"
+                    "Actual annotation bundle version: {actual}".format(
+                        expected=expected_bundle_version,
+                        actual=actual_bundle_version,
+                    )
+                )
+                raise AnnBundleVersionAssertionError(msg)
+
+        call["annotations"] = annotations
+        call[__TYPE__] = f"ANNOTATED_MATCH_{call.get(__TYPE__, 'CALL')}"
+
+    elif DocType.HEADER.is_a(call):
+        call[__CHILD__] = f"ANNOTATED_MATCH_{call.get(__CHILD__, 'CALL')}"
+
+    return call
+
+
 def annotate_calls(
     annotations_list, data, fields, annotation_bundle_version, filter_anns=None
 ):
