@@ -14,7 +14,7 @@ def process_transcript_batch(data, sdk=None):
     logger.get_logger().debug("get_transcripts_batch", **record)
 
     results = sdk.call_with_retry(
-        sdk.transcripts.get_transcripts_batch, **record
+        sdk.region_search.region_search_batch, **record
     )["results"]
 
     return results
