@@ -22,6 +22,7 @@ from . import (
     mitomap,
     gene_type,
     pli,
+    secondary_findings_genes,
 )
 
 __all__ = (
@@ -49,4 +50,5 @@ __all__ = (
     "mitomap",
     "gene_type",
     "pli",
+    "secondary_findings_genes",
 )
