@@ -1,32 +1,28 @@
 from cytoolz.curried import assoc, compose
 from genomoncology.parse.doctypes import DocType, __CHILD__, __TYPE__
 from genomoncology.pipeline.transformers import register, name_mapping
-
+from genomoncology.pipeline.transformers.functions import turn_gene_to_list
 
 NAME_MAPPING = {
     "gene": "gene",
-    "disease_name__mstring": "disease_name",
-    "disease_mim__mstring": "disease_mim",
+    "disease_name__string": "disease_name",
+    "disease_mim__string": "disease_mim",
 }
 
 
-def parse_gene(x):
-    return x["key"]
-
-
 register(
-    input_type=DocType.AGGREGATE,
+    input_type=DocType.TSV,
     output_type=DocType.SECONDARY_FINDINGS_GENES,
     transformer=compose(
         lambda x: assoc(x, "is_gene_annotation", True),
         lambda x: assoc(x, __TYPE__, DocType.SECONDARY_FINDINGS_GENES.value),
-        name_mapping(NAME_MAPPING),
-        lambda x: assoc(x, "gene", parse_gene(x)),
+        lambda x: assoc(x, "gene", turn_gene_to_list(x)),
+        name_mapping(NAME_MAPPING)
     ),
 )
 
 register(
-    input_type=DocType.AGGREGATE,
+    input_type=DocType.TSV,
     output_type=DocType.SECONDARY_FINDINGS_GENES,
     transformer=compose(
         lambda x: assoc(x, "is_gene_annotation", True),
