@@ -1,4 +1,5 @@
 import os
+
 import backoff
 import specd.sdk
 from configparser import ConfigParser
@@ -20,6 +21,7 @@ HTTP_EXCEPTIONS = (
     ConnectionError,
     TimeoutError,
     ClientConnectionError,
+    # HTTPGatewayTimeout,
 )
 MAX_TIME = 600
 
@@ -47,6 +49,8 @@ def construct_sdk(  # pragma: no mccabe
     enable_validation=False,
     config=None,
     max_time=MAX_TIME,
+    max_tries=12,
+    timeout=300,
 ):
 
     token = token or KMS_TOKEN
@@ -83,12 +87,15 @@ def construct_sdk(  # pragma: no mccabe
     if async_enabled:
 
         @backoff.on_exception(
-            backoff.expo, HTTP_EXCEPTIONS, max_time=max_time, max_tries=5
+            backoff.expo,
+            HTTP_EXCEPTIONS,
+            max_time=max_time,
+            max_tries=max_tries,
         )
         async def _async_with_retry(sdk_func, **kwargs):
             try:
                 return handle_errors(
-                    await sdk_func(**kwargs).result(timeout=300)
+                    await sdk_func(**kwargs).result(timeout=timeout)
                 )
 
             except HTTPInternalServerError as error:
@@ -105,11 +112,16 @@ def construct_sdk(  # pragma: no mccabe
     else:
 
         @backoff.on_exception(
-            backoff.expo, HTTP_EXCEPTIONS, max_time=max_time, max_tries=5
+            backoff.expo,
+            HTTP_EXCEPTIONS,
+            max_time=max_time,
+            max_tries=max_tries,
         )
         def _sync_with_retry(sdk_func, **kwargs):
             try:
-                return handle_errors(sdk_func(**kwargs).result(timeout=300))
+                return handle_errors(
+                    sdk_func(**kwargs).result(timeout=timeout)
+                )
 
             except HTTPInternalServerError as error:
                 logger.get_logger().error(
