@@ -19,6 +19,21 @@ class AnnotationList(BaseModel):
                 yield self.get_annotation(key)
 
 
+class AnnotationMatchList(BaseModel):
+    # Set of keys that are NOT annotations. New top-level keys must be added.
+    META_KEYS = {"errors", "is_created", "additionalProperties", "normalized"}
+
+    def get_annotation(self, key):
+        obj_dict = getattr(self, key, None)
+        if obj_dict:
+            return self.instantiate(self.definitions.AnnotationMatch, obj_dict)
+
+    def iter_annotations(self):
+        for key in self:
+            if key not in AnnotationMatchList.META_KEYS:
+                yield self.get_annotation(key)
+
+
 class VariantInterpretationResponse(BaseModel):
 
     # set of keys that are NOT part of the variant interpretations response
